@@ -10,6 +10,7 @@ from dataquality.clients.api import ApiClient
 from dataquality.clients.objectstore import ObjectStore
 from dataquality.exceptions import GalileoException, GalileoWarning
 from dataquality.schemas.dataframe import FileType
+from dataquality.schemas.edit import Edit
 from dataquality.schemas.metrics import FilterParams
 from dataquality.schemas.ner import TaggingSchema
 from dataquality.schemas.split import Split, conform_split
@@ -19,6 +20,37 @@ api_client = ApiClient()
 object_store = ObjectStore()
 
 
+def create_edit(
+    project_name: str,
+    run_name: str,
+    split: Split,
+    edit: Union[Edit, Dict],
+    filter: Union[FilterParams, Dict],
+    task: Optional[str] = None,
+    inference_name: Optional[str] = None,
+) -> Dict:
+    """Creates an edit for a run given a filter
+
+    :param project_name: The project name
+    :param run_name: The run name
+    :param split: The split
+    :param edit: The edit to make. see `help(Edit)` for more information
+    :param task: Required task name if run is MLTC
+    :param inference_name: Required inference name if split is inference
+    """
+    split = conform_split(split)
+    filter_params = _validate_filter(filter)
+    project_id, run_id = api_client._get_project_run_id(project_name, run_name)
+    edit = _conform_edit(edit)
+    edit.project_id = project_id
+    edit.run_id = run_id
+    edit.split = split
+    edit.task = task
+    edit.inference_name = inference_name
+    edit.filter = FilterParams(**filter_params)
+    return api_client.create_edit(edit)
+
+
 def get_run_summary(
     project_name: str,
     run_name: str,
@@ -561,6 +593,12 @@ def _validate_filter(filter: Union[FilterParams, Dict] = None) -> Dict:
     return FilterParams(**dict(filter or {})).dict()
 
 
+def _conform_edit(edit: Union[Edit, Dict]) -> Edit:
+    if isinstance(edit, Edit):
+        return edit
+    return Edit(**edit)
+
+
 def _clean_mltc_df(df: DataFrame) -> DataFrame:
     """In MLTC, don't return the non-task-indexes gold/pred/dep columns"""
     drop_cols = ["gold", "pred", "data_error_potential", "prob"]
